///////////////////////////////////////////////////////////////
// Tracker Add-on Example
// by Peter Hinely <phinely@hawaii.edu>
//
// Demonstration of how to migrate the functionality of a 
// Tracker add-on to a separate application so that Tracker 
// stability is not jepardized by bugs in the add-on
///////////////////////////////////////////////////////////////

#include "App.h"
#include "main.h"

App::App() : BApplication(FILE_SIGNATURE) {
	receivedRefs = false;
}

App::~App() { 
}


void App::MessageReceived(BMessage *msg)
{
	switch(msg->what){
		default:
			BApplication::MessageReceived(msg);
	}
}

void App::RefsReceived(BMessage *message) {
	receivedRefs = true;
	
	uint32 type;
	int32 count; 
	entry_ref ref; 
 
	message->GetInfo("refs", &type, &count); 
	if(type != B_REF_TYPE) {
		return;
	}

	uint32 numberOfFiles = 0;
	uint32 numberOfDirectories = 0;
	uint32 numberOfSymLinks = 0;
        
	for (uint32 i = 0; i < count && message->FindRef("refs", i, &ref) == B_OK; i++) {
		BEntry entry(&ref); 
		if (entry.IsFile()) {
			numberOfFiles++;
		}
		else if(entry.IsDirectory()) {
			numberOfDirectories++;
		}
		else if(entry.IsSymLink()) {
			numberOfSymLinks++;
		}
	}
	
	char textBuffer[256];
	sprintf(textBuffer, "Tracker Add-on Example\nby Peter Hinely <phinely@hawaii.edu>\n\n%u file(s), %u directory(s), and %u symbolic link(s) processed.", 
		numberOfFiles, numberOfDirectories, numberOfSymLinks);

	BAlert *alert = new BAlert("BAlert", textBuffer, "OK", NULL, NULL, B_WIDTH_AS_USUAL, B_INFO_ALERT); 
	alert->Go();

	PostMessage(B_QUIT_REQUESTED);
}

void App::ReadyToRun() {
	if(!receivedRefs) {
		BAlert *alert = new BAlert("BAlert", "Tracker Add-on Example\nby Peter Hinely <phinely@hawaii.edu>", "OK", NULL, NULL, B_WIDTH_AS_USUAL, B_INFO_ALERT); 
		alert->Go();
		PostMessage(B_QUIT_REQUESTED);
	}
}


